@@ -7,21 +7,19 @@ from airflow.exceptions import AirflowException
 from airflow.utils.file import TemporaryDirectory
 from dagster_airflow.vendor.docker_operator import DockerOperator
 from dagster_graphql.client.query import RAW_EXECUTE_PLAN_MUTATION
+from dagster_graphql.client.util import construct_variables, parse_raw_log_lines
 from docker import APIClient, from_env
 
-from dagster import check, seven
-from dagster.core.definitions.pipeline import ExecutionSelector
+from dagster import seven
 from dagster.core.events import EngineEventData
-from dagster.core.instance import DagsterInstance, InstanceRef
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster.core.instance import DagsterInstance
 from dagster.utils.error import serializable_error_info_from_exc_info
 
 from .util import (
+    add_airflow_tags,
     check_events_for_failures,
     check_events_for_skips,
-    construct_variables,
     get_aws_environment,
-    parse_raw_res,
 )
 
 DOCKER_TEMPDIR = '/tmp'
@@ -131,53 +129,18 @@ class DagsterDockerOperator(ModifiedDockerOperator):
 
     # py2 compat
     # pylint: disable=keyword-arg-before-vararg
-    def __init__(
-        self,
-        task_id,
-        pipeline_name,
-        mode,
-        environment_dict=None,
-        step_keys=None,
-        dag=None,
-        instance_ref=None,
-        *args,
-        **kwargs
-    ):
-        check.str_param(pipeline_name, 'pipeline_name')
-        step_keys = check.opt_list_param(step_keys, 'step_keys', of_type=str)
-        environment_dict = check.opt_dict_param(environment_dict, 'environment_dict', key_type=str)
-        check.opt_inst_param(instance_ref, 'instance_ref', InstanceRef)
-
+    def __init__(self, dagster_operator_parameters, *args):
+        kwargs = dagster_operator_parameters.op_kwargs
         tmp_dir = kwargs.pop('tmp_dir', DOCKER_TEMPDIR)
         host_tmp_dir = kwargs.pop('host_tmp_dir', seven.get_system_temp_directory())
 
-        if not environment_dict.get('storage'):
-            raise AirflowException(
-                'No storage config found -- must configure storage for '
-                'the DagsterDockerOperator. Ex.: \n'
-                'storage:\n'
-                '  filesystem:\n'
-                '    config:'
-                '      base_dir: \'/some/shared/volume/mount/special_place\''
-                '\n\n --or--\n\n'
-                'storage:\n'
-                '  s3:\n'
-                '    s3_bucket: \'my-s3-bucket\'\n'
-                '\n\n --or--\n\n'
-                'storage:\n'
-                '  gcs:\n'
-                '    gcs_bucket: \'my-gcs-bucket\'\n'
-            )
-
-        if 'filesystem' in environment_dict['storage']:
+        run_config = dagster_operator_parameters.run_config
+        if 'filesystem' in run_config['storage']:
             if (
-                'config' in (environment_dict['storage'].get('filesystem', {}) or {})
+                'config' in (run_config['storage'].get('filesystem', {}) or {})
                 and 'base_dir'
-                in (
-                    (environment_dict['storage'].get('filesystem', {}) or {}).get('config', {})
-                    or {}
-                )
-                and environment_dict['storage']['filesystem']['config']['base_dir'] != tmp_dir
+                in ((run_config['storage'].get('filesystem', {}) or {}).get('config', {}) or {})
+                and run_config['storage']['filesystem']['config']['base_dir'] != tmp_dir
             ):
                 warnings.warn(
                     'Found base_dir \'{base_dir}\' set in filesystem storage config, which was not '
@@ -185,18 +148,18 @@ class DagsterDockerOperator(ModifiedDockerOperator):
                     '\'{host_tmp_dir}\' from the host). We assume you know what you are doing, but '
                     'if you are having trouble executing containerized workloads, this may be the '
                     'issue'.format(
-                        base_dir=environment_dict['storage']['filesystem']['config']['base_dir'],
+                        base_dir=run_config['storage']['filesystem']['config']['base_dir'],
                         tmp_dir=tmp_dir,
                         host_tmp_dir=host_tmp_dir,
                     )
                 )
             else:
-                environment_dict['storage']['filesystem'] = dict(
-                    environment_dict['storage']['filesystem'] or {},
+                run_config['storage']['filesystem'] = dict(
+                    run_config['storage']['filesystem'] or {},
                     **{
                         'config': dict(
                             (
-                                (environment_dict['storage'].get('filesystem', {}) or {}).get(
+                                (run_config['storage'].get('filesystem', {}) or {}).get(
                                     'config', {}
                                 )
                                 or {}
@@ -207,14 +170,22 @@ class DagsterDockerOperator(ModifiedDockerOperator):
                 )
 
         self.docker_conn_id_set = kwargs.get('docker_conn_id') is not None
-        self.environment_dict = environment_dict
-        self.pipeline_name = pipeline_name
-        self.mode = mode
-        self.step_keys = step_keys
+        self.run_config = run_config
+        self.pipeline_name = dagster_operator_parameters.pipeline_name
+        self.pipeline_snapshot = dagster_operator_parameters.pipeline_snapshot
+        self.execution_plan_snapshot = dagster_operator_parameters.execution_plan_snapshot
+        self.parent_pipeline_snapshot = dagster_operator_parameters.parent_pipeline_snapshot
+        self.mode = dagster_operator_parameters.mode
+        self.step_keys = dagster_operator_parameters.step_keys
+        self.recon_repo = dagster_operator_parameters.recon_repo
         self._run_id = None
         # self.instance might be None in, for instance, a unit test setting where the operator
         # was being directly instantiated without passing through make_airflow_dag
-        self.instance = DagsterInstance.from_ref(instance_ref) if instance_ref else None
+        self.instance = (
+            DagsterInstance.from_ref(dagster_operator_parameters.instance_ref)
+            if dagster_operator_parameters.instance_ref
+            else None
+        )
 
         # These shenanigans are so we can override DockerOperator.get_hook in order to configure
         # a docker client using docker.from_env, rather than messing with the logic of
@@ -238,7 +209,12 @@ class DagsterDockerOperator(ModifiedDockerOperator):
             kwargs['environment'] = get_aws_environment()
 
         super(DagsterDockerOperator, self).__init__(
-            task_id=task_id, dag=dag, tmp_dir=tmp_dir, host_tmp_dir=host_tmp_dir, *args, **kwargs
+            task_id=dagster_operator_parameters.task_id,
+            dag=dagster_operator_parameters.dag,
+            tmp_dir=tmp_dir,
+            host_tmp_dir=host_tmp_dir,
+            *args,
+            **kwargs
         )
 
     @property
@@ -250,23 +226,20 @@ class DagsterDockerOperator(ModifiedDockerOperator):
 
     @property
     def query(self):
-        # TODO: https://github.com/dagster-io/dagster/issues/1342
-        redacted = construct_variables(
-            self.mode, 'REDACTED', self.pipeline_name, self.run_id, self.airflow_ts, self.step_keys
+        variables = construct_variables(
+            self.recon_repo,
+            self.mode,
+            self.run_config,
+            self.pipeline_name,
+            self.run_id,
+            self.step_keys,
         )
+        variables = add_airflow_tags(variables, self.airflow_ts)
+
         self.log.info(
             'Executing GraphQL query: {query}\n'.format(query=RAW_EXECUTE_PLAN_MUTATION)
             + 'with variables:\n'
-            + seven.json.dumps(redacted, indent=2)
-        )
-
-        variables = construct_variables(
-            self.mode,
-            self.environment_dict,
-            self.pipeline_name,
-            self.run_id,
-            self.airflow_ts,
-            self.step_keys,
+            + seven.json.dumps(variables, indent=2)
         )
 
         return 'dagster-graphql -v \'{variables}\' -t \'{query}\''.format(
@@ -311,36 +284,39 @@ class DagsterDockerOperator(ModifiedDockerOperator):
         elif 'dag_run' in context and context['dag_run'] is not None:
             self._run_id = context['dag_run'].run_id
 
-        pipeline_run = PipelineRun(
-            pipeline_name=self.pipeline_name,
-            run_id=self.run_id,
-            environment_dict=self.environment_dict,
-            mode=self.mode,
-            selector=ExecutionSelector(self.pipeline_name),
-            step_keys_to_execute=None,
-            tags=None,
-            status=PipelineRunStatus.MANAGED,
-        )
         try:
             if self.instance:
-                self.instance.get_or_create_run(pipeline_run)
+                run = self.instance.register_managed_run(
+                    pipeline_name=self.pipeline_name,
+                    run_id=self.run_id,
+                    run_config=self.run_config,
+                    mode=self.mode,
+                    solids_to_execute=None,
+                    step_keys_to_execute=None,
+                    tags=None,
+                    root_run_id=None,
+                    parent_run_id=None,
+                    pipeline_snapshot=self.pipeline_snapshot,
+                    execution_plan_snapshot=self.execution_plan_snapshot,
+                    parent_pipeline_snapshot=self.parent_pipeline_snapshot,
+                )
 
             raw_res = super(DagsterDockerOperator, self).execute(context)
             self.log.info('Finished executing container.')
 
-            res = parse_raw_res(raw_res)
+            res = parse_raw_log_lines(raw_res)
 
             try:
                 handle_execution_errors(res, 'executePlan')
             except DagsterGraphQLClientError as err:
                 if self.instance:
                     self.instance.report_engine_event(
-                        self.__class__,
                         str(err),
-                        pipeline_run,
+                        run,
                         EngineEventData.engine_error(
                             serializable_error_info_from_exc_info(sys.exc_info())
                         ),
+                        self.__class__,
                     )
                 raise
 
