@@ -1,29 +1,27 @@
 # pylint: disable=redefined-outer-name, unused-argument
 
 import os
-import sys
 
 import pytest
 from airflow.exceptions import AirflowException
 from airflow.utils import timezone
-from dagster_airflow.factory import make_airflow_dag_kubernetized_for_handle
+from dagster_airflow.factory import make_airflow_dag_kubernetized_for_recon_repo
 from dagster_airflow.test_fixtures import (  # pylint: disable=unused-import
     dagster_airflow_k8s_operator_pipeline,
     execute_tasks_in_dag,
 )
-from dagster_airflow_tests.marks import nettest
+from dagster_airflow_tests.marks import nettest, requires_k8s
+from dagster_test.test_project import test_project_environments_path
 
-from dagster import ExecutionTargetHandle
+from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.utils import make_new_run_id
-from dagster.utils import git_repository_root, load_yaml_from_glob_list
+from dagster.utils import load_yaml_from_glob_list
 
 from .utils import validate_pipeline_execution
 
-sys.path.append(os.path.join(git_repository_root(), 'python_modules', 'libraries', 'dagster-k8s'))
-from dagster_k8s_tests.test_project import test_project_environments_path  # isort:skip
-
 
 @nettest
+@requires_k8s
 def test_s3_storage(dagster_airflow_k8s_operator_pipeline, dagster_docker_image, cluster_provider):
     print('--- :airflow: test_kubernetes.test_s3_storage')
     _check_aws_creds_available()
@@ -32,7 +30,9 @@ def test_s3_storage(dagster_airflow_k8s_operator_pipeline, dagster_docker_image,
     pipeline_name = 'demo_pipeline'
     results = dagster_airflow_k8s_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'test_pipelines.repo', 'define_demo_execution_repo'
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_s3.yaml'),
@@ -50,6 +50,7 @@ def test_s3_storage(dagster_airflow_k8s_operator_pipeline, dagster_docker_image,
 
 
 @nettest
+@requires_k8s
 def test_gcs_storage(
     dagster_airflow_k8s_operator_pipeline, dagster_docker_image, cluster_provider,
 ):
@@ -60,7 +61,9 @@ def test_gcs_storage(
     pipeline_name = 'demo_pipeline_gcs'
     results = dagster_airflow_k8s_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'test_pipelines.repo', 'define_demo_execution_repo'
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_gcs.yaml'),
@@ -71,27 +74,30 @@ def test_gcs_storage(
     validate_pipeline_execution(results)
 
 
+@requires_k8s
 def test_error_dag_k8s(dagster_docker_image, cluster_provider):
     print('--- :airflow: test_kubernetes.test_error_dag_k8s')
     _check_aws_creds_available()
 
     pipeline_name = 'demo_error_pipeline'
-    handle = ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name)
+    recon_repo = ReconstructableRepository.for_module(
+        'test_pipelines.repo', 'define_demo_execution_repo'
+    )
     environments_path = test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, 'env_s3.yaml'),
     ]
-    environment_dict = load_yaml_from_glob_list(environment_yaml)
+    run_config = load_yaml_from_glob_list(environment_yaml)
 
     run_id = make_new_run_id()
     execution_date = timezone.utcnow()
 
-    dag, tasks = make_airflow_dag_kubernetized_for_handle(
-        handle=handle,
+    dag, tasks = make_airflow_dag_kubernetized_for_recon_repo(
+        recon_repo=recon_repo,
         pipeline_name=pipeline_name,
         image=dagster_docker_image,
         namespace='default',
-        environment_dict=environment_dict,
+        run_config=run_config,
         op_kwargs={
             'config_file': os.environ['KUBECONFIG'],
             'env_vars': {
